@@ -10,8 +10,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and limitations under the License.
 
-context("testing options")
-
 test_that("bcdc_options() returns a tibble",{
   skip_if_net_down()
   skip_on_cran()
@@ -23,23 +21,29 @@ test_that("bcdc_options() returns a tibble",{
 test_that("bcdata.chunk_limit",{
   skip_if_net_down()
   skip_on_cran()
-  withr::local_options(list(bcdata.chunk_limit = 10000))
-  expect_error(check_chunk_limit())
+  withr::with_options(list(bcdata.chunk_limit = 100000), {
+    expect_error(check_chunk_limit())
+  })
+  withr::with_options(list(bcdata.chunk_limit = 10), {
+    expect_true(is.numeric(check_chunk_limit()))
+    expect_equal(check_chunk_limit(), 10)
+  })
 })
 
-test_that("bcdata.single_download_limit", {
+test_that("bcdata.single_download_limit is deprecated but works", {
+  # This can be removed when bcdata.single_download_limit is removed
   skip_if_net_down()
   skip_on_cran()
   withr::local_options(list(bcdata.single_download_limit = 1))
-  expect_message(
-    bcdc_get_data(record = '76b1b7a3-2112-4444-857a-afccf7b20da8', resource =
-                    '4d0377d9-e8a1-429b-824f-0ce8f363512c'),
-    "paginated"
+  withr::local_envvar(list(BCDC_KEY = NULL)) # so snapshot not affected by message
+  expect_s3_class(
+    bcdc_query_geodata(record = '76b1b7a3-2112-4444-857a-afccf7b20da8'), 
+    "bcdc_promise"
   )
-
 })
 
 test_that("bcdata.single_download_limit can be changed",{
+  # This can be removed when bcdata.single_download_limit is removed
   skip_if_net_down()
   skip_on_cran()
   withr::local_options(list(bcdata.single_download_limit = 13))
